@@ -443,7 +443,7 @@ class XMLRPCCommand(Command):
         except InsufficientServerVersion as ex:
             print >> sys.stderr, ("This command requires at least server version "
                                   "%s, actual server version is %s" %
-                                 (ex.required_version, ex.server_version))
+                                  (ex.required_version, ex.server_version))
 
     def invoke(self):
         with self.safety_net():
@@ -679,116 +679,6 @@ class make_stream(XMLRPCCommand):
         print "Bundle stream {pathname} created".format(pathname=pathname)
 
 
-class backup(XMLRPCCommand):
-
-    """
-    Backup data uploaded to a dashboard instance.
-    Not all data is preserved. The following data is lost: identity of the user
-    that uploaded each bundle, time of uploading and deserialization on the
-    server, name of the bundle stream that contained the data
-    """
-
-    @classmethod
-    def register_arguments(cls, parser):
-        super(backup, cls).register_arguments(parser)
-        parser.add_argument("BACKUP_DIR", type=str,
-                            help="Directory to backup to")
-
-    def invoke_remote(self):
-        if not os.path.exists(self.args.BACKUP_DIR):
-            os.mkdir(self.args.BACKUP_DIR)
-        for bundle_stream in self.server.streams():
-            print "Processing stream %s" % bundle_stream["pathname"]
-            bundle_stream_dir = os.path.join(
-                self.args.BACKUP_DIR,
-                urllib.quote_plus(bundle_stream["pathname"]))
-            if not os.path.exists(bundle_stream_dir):
-                os.mkdir(bundle_stream_dir)
-            with open(os.path.join(bundle_stream_dir, "metadata.json"), "wt") as stream:
-                simplejson.dump({
-                    "pathname": bundle_stream["pathname"],
-                    "name": bundle_stream["name"],
-                    "user": bundle_stream["user"],
-                    "group": bundle_stream["group"],
-                }, stream)
-            for bundle in self.server.bundles(bundle_stream["pathname"]):
-                print " * Backing up bundle %s" % bundle["content_sha1"]
-                data = self.server.get(bundle["content_sha1"])
-                bundle_pathname = os.path.join(
-                    bundle_stream_dir,
-                    bundle["content_sha1"])
-                # Note: we write bundles as binary data to preserve anything
-                # the user might have dumped on us
-                with open(bundle_pathname + ".json", "wb") as stream:
-                    stream.write(data["content"])
-                with open(bundle_pathname + ".metadata.json", "wt") as stream:
-                    simplejson.dump({
-                        "uploaded_by": bundle["uploaded_by"],
-                        "uploaded_on":
-                        datetime_extension.to_json(bundle["uploaded_on"]),
-                        "content_filename": bundle["content_filename"],
-                        "content_sha1": bundle["content_sha1"],
-                        "content_size": bundle["content_size"],
-                    }, stream)
-
-
-class restore(XMLRPCCommand):
-
-    """
-    Restore a dashboard instance from backup
-    """
-
-    @classmethod
-    def register_arguments(cls, parser):
-        super(restore, cls).register_arguments(parser)
-        parser.add_argument("BACKUP_DIR", type=str,
-                            help="Directory to backup from")
-
-    def invoke_remote(self):
-        self._check_server_version(self.server, "0.3")
-        for stream_pathname_quoted in os.listdir(self.args.BACKUP_DIR):
-            filesystem_stream_pathname = os.path.join(
-                self.args.BACKUP_DIR,
-                stream_pathname_quoted)
-            if not os.path.isdir(filesystem_stream_pathname):
-                continue
-            stream_pathname = urllib.unquote(stream_pathname_quoted)
-            if os.path.exists(os.path.join(filesystem_stream_pathname, "metadata.json")):
-                with open(os.path.join(filesystem_stream_pathname, "metadata.json"), "rt") as stream:
-                    stream_metadata = simplejson.load(stream)
-            else:
-                stream_metadata = {}
-            print "Processing stream %s" % stream_pathname
-            try:
-                self.server.make_stream(
-                    stream_pathname,
-                    stream_metadata.get(
-                        "name",
-                        "Restored from backup"))
-            except xmlrpclib.Fault as ex:
-                if ex.faultCode != 409:
-                    raise
-            for content_sha1 in [item[:-len(".json")] for item in os.listdir(filesystem_stream_pathname) if item.endswith(".json") and not item.endswith(".metadata.json") and item != "metadata.json"]:
-                filesystem_content_filename = os.path.join(
-                    filesystem_stream_pathname,
-                    content_sha1 + ".json")
-                if not os.path.isfile(filesystem_content_filename):
-                    continue
-                with open(os.path.join(filesystem_stream_pathname, content_sha1) + ".metadata.json", "rt") as stream:
-                    bundle_metadata = simplejson.load(stream)
-                with open(filesystem_content_filename, "rb") as stream:
-                    content = stream.read()
-                print " * Restoring bundle %s" % content_sha1
-                try:
-                    self.server.put(
-                        content,
-                        bundle_metadata["content_filename"],
-                        stream_pathname)
-                except xmlrpclib.Fault as ex:
-                    if ex.faultCode != 409:
-                        raise
-
-
 class pull(XMLRPCCommand):
     """
     Copy bundles and bundle streams from one dashboard to another.
