@@ -19,4 +19,4 @@
 
 
 def version():
-    return "0.11.2"
+    return "0.12"
